=================
Engage Django SDK
=================

Engage is an open source platform for deploying and managing
applications, either on your own servers or in the public cloud.
It automates server provisioning, application installation,
configuration, and upgrades.

This Python package distribution is an SDK which enables you to
package your Django applications for deployment via Engage. 
Currently, only deployment on genForma's servers is supported.
Support for deploying on your own servers (or development machine)
will be forthcoming in a future release. If you would like to
participate in beta testing of either the cloud or on-premises version
of Engage, please contact support@genforma.com.

Two documents are available to help you with this SDK:
 1. The Quickstart Guide at http://beta.genforma.com/doc-django-quickstart.html (also available in source form in the included quickstart_guide.rst file).
 2. The Reference manual at http://beta.genforma.com/sdk_refman/index.html (also available in source form in the refman subdirectory).


Installation
============
This package requires setuptools
(http://pypi.python.org/pypi/setuptools).  If you download the SDK
archive to your system, you can install it using *easy_install* as follows::

  easy_install <archive_name>

Alternatively, you can use *pip* for the installation. You can also
skip the downloading step and install it directly from the Python
Package Index (http://pypi.python.org)::

  easy_install engage_django_sdk


Notice
======
Engage and the Engage SDK is copyright 2010, 2011 by the genForma
Corporation. It is made available under the Apache V2.0 license.

This distribution does not include any third party software.

Authors
=======
The following people contributed to this software:
 * Jay Doane (jay at almery dot com)
 * Jeff Fischer (jeffrey dot fischer at genforma dot com)
 * Rupak Majumdar (rupak at mpi-sws dot org)

